@@ -12,6 +12,7 @@ from meutils.common import *
 from meutils.np_utils import normalize
 from meutils.zk_utils import get_zk_config
 from appzoo import App
+from mi.db import Mongo
 
 import tensorflow as tf
 
@@ -23,6 +24,10 @@ from bert4keras.models import build_transformer_model
 from bert4keras.tokenizers import Tokenizer
 from bert4keras.snippets import sequence_padding
 
+# collection
+m = Mongo()
+cache_bert = m.db['cache_bert']
+
 # BERT_DIR
 BERT_DIR = './chinese_simbert_L-12_H-768_A-12'
 fds_url = get_zk_config("/mipush/cfg")['fds_url']
@@ -73,28 +78,30 @@ def texts2vec(texts):
     return vecs
 
 
-def cache_mongodb(**kwargs):  # todo: Mongo
-    pass
-
-
 def get_one_vec(**kwargs):
     text = kwargs.get('text', '默认')
-    is_lite = kwargs.get('is_lite', 0)
+    is_lite = kwargs.get('is_lite', '0')
 
-    vecs = text2vec(text)
-    if is_lite:
-        vecs = vecs[:, range(0, 768, 4)]  # 64*3 = 192维度
-
-    return normalize(vecs).tolist()
+    doc = cache_bert.find_one({'text': text, 'is_lite': is_lite})
+    if doc:
+        logger.info(f'dup key: {text}')
+        return [doc['vector']]
+    else:
+        vecs = text2vec(text)
+        if is_lite == '1':
+            vecs = vecs[:, range(0, 768, 4)]  # 64*3 = 192维度
+        vecs = normalize(vecs).tolist()
+        cache_bert.insert_one({'text': text, 'is_lite': is_lite, 'vector': vecs[0]})
+        return vecs
 
 
 def get_batch_vec(**kwargs):
     texts = kwargs.get('texts', ['默认'])
-    is_lite = kwargs.get('is_lite', 0)
+    is_lite = kwargs.get('is_lite', '0')
 
     vecs = texts2vec(texts)
 
-    if is_lite:
+    if is_lite == '1':
         vecs = vecs[:, range(0, 768, 4)]  # 64*3 = 192维度
 
     return normalize(vecs).tolist()
